@@ -72,6 +72,16 @@ struct _ClearlooksStyle
 	GdkGC *spot1_gc;
 	GdkGC *spot2_gc;
 	GdkGC *spot3_gc;
+	
+	GdkColor inset_light[5];
+	GdkColor inset_dark[5];
+	
+	GdkColor button_g1[5];
+	GdkColor button_g2[5];
+	GdkColor button_g3[5];
+	GdkColor button_g4[5];
+	
+	GdkColor listview_bg[5];
 
 	GdkPixmap *radio_pixmap_nonactive[5];
 	GdkPixmap *radio_pixmap_active[5];
@@ -82,7 +92,7 @@ struct _ClearlooksStyle
 	GdkPixmap *check_pixmap_active[5];
 	GdkPixmap *check_pixmap_inconsistent[5];
 	
-	gboolean sunkenmenubar:1;
+	guint sunkenmenubar:1;
 
 	guint8   progressbarstyle;
 	guint8   menubarstyle;
