@@ -9,14 +9,11 @@
 #include <math.h>
 #include <string.h>
 
-#define DEBUG 0
+/* #define DEBUG 1 */
 
 #define DETAIL(xx) ((detail) != 0 && strcmp (xx, detail) == 0)
 
-/* Focus change hooks */
-#define WINDOW_FOCUS_DATA_KEY "eazel-engine-focus-data"
-static GQuark window_focus_data_key;
-GtkStyleClass *parent_style_class;
+static GtkStyleClass *parent_style_class;
 
 typedef struct focus_change_data_struct focus_change_data;
 struct focus_change_data_struct {
@@ -30,7 +27,6 @@ struct focus_change_data_struct {
     guint destroyed_signal_id;
 };
 
-static GSList *focus_data_list = NULL;
 
 static void
 draw_hline (GtkStyle *style,
@@ -95,15 +91,6 @@ draw_diamond (GtkStyle *style,
 	      GtkWidget *widget,
 	      const gchar *detail, gint x, gint y, gint width, gint height);
 
-static void
-draw_oval (GtkStyle *style,
-	   GdkWindow *window,
-	   GtkStateType state_type,
-	   GtkShadowType shadow_type,
-	   GdkRectangle *area,
-	   GtkWidget *widget,
-	   const gchar *detail, gint x, gint y, gint width, gint height);
-
 static void
 draw_string (GtkStyle *style,
 	     GdkWindow *window,
@@ -111,6 +98,7 @@ draw_string (GtkStyle *style,
 	     GdkRectangle *area,
 	     GtkWidget *widget,
 	     const gchar *detail, gint x, gint y, const gchar *string);
+#if 0
 static void
 draw_flat_box (GtkStyle *style,
 	       GdkWindow *window,
@@ -119,6 +107,7 @@ draw_flat_box (GtkStyle *style,
 	       GdkRectangle *area,
 	       GtkWidget *widget,
 	       const gchar *detail, gint x, gint y, gint width, gint height);
+#endif
 
 static void
 draw_check (GtkStyle *style,
@@ -137,25 +126,6 @@ draw_option (GtkStyle *style,
 	     GtkWidget *widget,
 	     const gchar *detail, gint x, gint y, gint width, gint height);
 
-static void
-draw_cross (GtkStyle *style,
-	    GdkWindow *window,
-	    GtkStateType state_type,
-	    GtkShadowType shadow_type,
-	    GdkRectangle *area,
-	    GtkWidget *widget,
-	    const gchar *detail, gint x, gint y, gint width, gint height);
-
-static void
-draw_ramp (GtkStyle *style,
-	   GdkWindow *window,
-	   GtkStateType state_type,
-	   GtkShadowType shadow_type,
-	   GdkRectangle *area,
-	   GtkWidget *widget,
-	   const gchar *detail,
-	   GtkArrowType arrow_type, gint x, gint y, gint width, gint height);
-
 static void
 draw_tab (GtkStyle *style,
 	  GdkWindow *window,
@@ -239,153 +209,17 @@ draw_handle (GtkStyle *style,
 	     gint y, gint width, gint height, GtkOrientation orientation);
 
 
-static focus_change_data *
-get_focus_data (GtkWidget *widget, gboolean add)
-{
-    GtkWidget *toplevel = gtk_widget_get_toplevel (widget);
-    focus_change_data *data = gtk_object_get_data_by_id (GTK_OBJECT (toplevel),
-							 window_focus_data_key);
-    if (data == 0 && add)
-    {
-	data = g_new0 (focus_change_data, 1);
-	data->widget = widget;
-	gtk_object_set_data_by_id_full (GTK_OBJECT (toplevel),
-					window_focus_data_key,
-					data, g_free);
-	focus_data_list = g_slist_prepend (focus_data_list, data);
-    }
-
-    return data;
-}
-
-static void
-focus_change_helper (GtkWidget *widget, gpointer data)
-{
-    if (GTK_IS_CONTAINER (widget))
-    {
-	gtk_container_forall (GTK_CONTAINER (widget),
-			      focus_change_helper, NULL);
-    }
-    else if (GTK_IS_RANGE (widget))
-    {
-	gtk_widget_queue_draw (widget);
-    }
-    else if (GTK_IS_PROGRESS (widget))
-    {
-	/* This is horrible. But the GtkProgress widget stores the
-	   progress bar in a pixmap, then blits it on expose. But
-	   it will refresh the pixmap when asked to resize.. */
-	if (GTK_WIDGET_DRAWABLE (widget))
-	    gtk_widget_queue_resize (widget);
-    }
-}
-
-static void
-window_focus_in_callback (GtkWidget *window, GdkEventFocus *event,
-			  focus_change_data *data)
-{
-  printf ("focus in\n");
-    data->is_focused = TRUE;
-    gtk_container_forall (GTK_CONTAINER (window),
-			  focus_change_helper, NULL);
-}
-
-static void
-window_focus_out_callback (GtkWidget *window, GdkEventFocus *event,
-			   focus_change_data *data)
-{
-  printf ("focus out\n");
-    data->is_focused = FALSE;
-    gtk_container_forall (GTK_CONTAINER (window),
-			  focus_change_helper, NULL);
-}
-
-static void
-window_destroyed_callback (GtkWidget *window, focus_change_data *data)
-{
-    focus_data_list = g_slist_remove (focus_data_list, data);
-}
-
-gboolean
-eazel_engine_widget_in_focused_window_p (GtkWidget *widget)
-{
-  focus_change_data *data = get_focus_data (widget, FALSE);
-  return TRUE;
-
-  if (data) {
-    printf ("there was data\n");
-    printf ("data->is_focused: %d\n", data->is_focused);
-  } else {
-    printf ("there was no data\n");
-  }
-  return (data != 0) ? data->is_focused : FALSE;
-}
-
-static void
-install_focus_hooks (GdkWindow *window)
-{
-    /* Evilness */
-    GtkWidget *widget;
-    gdk_window_get_user_data (window, (gpointer *) &widget);
-
-    printf ("installing focus hooks\n");
-    if (widget != NULL && GTK_IS_WINDOW (widget))
-    {
-	focus_change_data *data = get_focus_data (widget, TRUE);
-	if (!data->connected)
-	{
-	    /* Connect to this window so we get focus-in/out events */
-	    data->focus_in_signal_id
-		= g_signal_connect (GTK_OBJECT (widget), "focus_in_event",
-				      GTK_SIGNAL_FUNC(window_focus_in_callback), data);
-	    data->focus_out_signal_id
-		= g_signal_connect (GTK_OBJECT (widget), "focus_out_event",
-				      GTK_SIGNAL_FUNC(window_focus_out_callback), data);
-	    data->destroyed_signal_id
-		= g_signal_connect (GTK_OBJECT (widget), "destroy",
-				      GTK_SIGNAL_FUNC(window_destroyed_callback), data);
-
-	    data->connected = TRUE;
-	}
-    }
-}
-
-void
-uninstall_all_focus_hooks (void)
-{
-    GSList *ptr;
-    for (ptr = focus_data_list; ptr != 0; ptr = ptr->next)
-    {
-	focus_change_data *data = ptr->data;
-	if (data->connected)
-	{
-	    gtk_signal_disconnect (GTK_OBJECT (data->widget),
-				   data->focus_in_signal_id);
-	    gtk_signal_disconnect (GTK_OBJECT (data->widget),
-			       data->focus_out_signal_id);
-	    gtk_signal_disconnect (GTK_OBJECT (data->widget),
-				   data->destroyed_signal_id);
-	}
-	gtk_object_remove_data_by_id (GTK_OBJECT (data->widget),
-				      window_focus_data_key);
-    }
-    g_slist_free (focus_data_list);
-    focus_data_list = NULL;
-}
-
-
 /* utility functions */
 
 static inline void
 debug (const char *fmt, ...)
 {
-    if (DEBUG)
-    {
+#ifdef DEBUG
 	va_list args;
 	va_start (args, fmt);
 	vfprintf (stderr, fmt, args);
 	va_end (args);
-    }
+#endif
 }
 
 /* adapted from nautilus-gdk-extensions.c */
@@ -1015,7 +849,7 @@ draw_shadow (GtkStyle *style,
     GdkGC *gc_a, *gc_b, *gc_c, *gc_d;
     gint thickness_light;
     gint thickness_dark;
-    gboolean rounded = FALSE, rounded_inner = FALSE;
+    gboolean rounded = FALSE;
     gboolean outline = TRUE;
     gint i;
 
@@ -1083,7 +917,7 @@ draw_shadow (GtkStyle *style,
     {
 	/* Clist title buttons have square edges */
 	if (widget == 0 || !GTK_IS_CLIST (widget->parent))
-	    rounded = rounded_inner = TRUE;
+	    rounded = TRUE;
     }
     else if (DETAIL ("menuitem"))
     {
@@ -1333,7 +1167,7 @@ draw_box (GtkStyle *style,
 	    if (state_type != GTK_STATE_INSENSITIVE)
 	    {
 		gboolean focused;
-		focused = eazel_engine_widget_in_focused_window_p (widget);
+		focused = TRUE;
 		paint_stock_image (theme_data,
 				   focused ? EAZEL_ENGINE_PROGRESS_BAR
 				   : EAZEL_ENGINE_PROGRESS_BAR_INACTIVE,
@@ -1913,19 +1747,6 @@ draw_diamond (GtkStyle *style,
     }
 }
 
-static void
-draw_oval (GtkStyle *style,
-	   GdkWindow *window,
-	   GtkStateType state_type,
-	   GtkShadowType shadow_type,
-	   GdkRectangle *area,
-	   GtkWidget *widget,
-	   const gchar *detail, gint x, gint y, gint width, gint height)
-{
-    g_return_if_fail (style != NULL);
-    g_return_if_fail (window != NULL);
-}
-
 static void
 draw_string (GtkStyle *style,
 	     GdkWindow *window,
@@ -1960,6 +1781,7 @@ draw_string (GtkStyle *style,
     }
 }
 
+#if 0
 static void
 draw_flat_box (GtkStyle *style,
 	       GdkWindow *window,
@@ -2020,6 +1842,7 @@ draw_flat_box (GtkStyle *style,
 	gtk_style_apply_default_pixmap (style, window, state_type, area, x,
 					y, width, height);
 }
+#endif
 
 static void
 paint_check (GtkStyle *style,
@@ -2144,33 +1967,6 @@ draw_option (GtkStyle *style,
 		 widget, detail, x, y, width, height, EAZEL_ENGINE_OPTION);
 }
 
-static void
-draw_cross (GtkStyle *style,
-	    GdkWindow *window,
-	    GtkStateType state_type,
-	    GtkShadowType shadow_type,
-	    GdkRectangle *area,
-	    GtkWidget *widget,
-	    const gchar *detail, gint x, gint y, gint width, gint height)
-{
-    g_return_if_fail (style != NULL);
-    g_return_if_fail (window != NULL);
-}
-
-static void
-draw_ramp (GtkStyle *style,
-	   GdkWindow *window,
-	   GtkStateType state_type,
-	   GtkShadowType shadow_type,
-	   GdkRectangle *area,
-	   GtkWidget *widget,
-	   const gchar *detail,
-	   GtkArrowType arrow_type, gint x, gint y, gint width, gint height)
-{
-    g_return_if_fail (style != NULL);
-    g_return_if_fail (window != NULL);
-}
-
 static void
 draw_tab (GtkStyle *style,
 	  GdkWindow *window,
@@ -2321,6 +2117,8 @@ draw_extension (GtkStyle *style,
 		gint y, gint width, gint height, GtkPositionType gap_side)
 {
     GdkRectangle rect;
+	GtkWidget* parent_widget;
+	gint relative_x;
 
     eazel_theme_data *theme_data;
 
@@ -2334,8 +2132,6 @@ draw_extension (GtkStyle *style,
 	    detail, state_type, shadow_type, x, y, width, height);
 
 	/* Get x relative to parent widget, not window */
-	GtkWidget* parent_widget;
-	gint relative_x;
 	if (widget != NULL)
 	{
 		parent_widget = gtk_widget_get_parent(widget);
@@ -2463,12 +2259,12 @@ draw_focus (GtkStyle *style,
 	{
 		if (area)
 			gdk_gc_set_clip_rectangle (style->black_gc, area);
-		if (DETAIL ("button"))
+		/* if (DETAIL ("button"))
 		{
-			//x -= theme_data->focus_thickness; y -= theme_data->focus_thickness;
-			//width += theme_data->focus_thickness * 2; height += theme_data->focus_thickness * 2;
+			x -= theme_data->focus_thickness; y -= theme_data->focus_thickness;
+			width += theme_data->focus_thickness * 2; height += theme_data->focus_thickness * 2;
 		}
-		else if (DETAIL ("text") || DETAIL ("entry"))
+		else */ if (DETAIL ("text") || DETAIL ("entry"))
 		{
 			rounded_inner = FALSE;
 		}
@@ -2523,14 +2319,11 @@ draw_slider (GtkStyle *style,
     if (area)
 	gdk_gc_set_clip_rectangle (style->black_gc, area);
 
-    focused = (widget != 0) && eazel_engine_widget_in_focused_window_p (widget);
+    focused = TRUE;
 
     if (DETAIL ("slider")) {
 	{
 	    int thumb_x, thumb_y;
-	    gboolean focused;
-
-	    focused = eazel_engine_widget_in_focused_window_p (widget);
 
 	    /* XXX could be a gradient? */
 	    paint_stock_image (theme_data,
@@ -2687,7 +2480,7 @@ crux_draw_style_class_init (GtkStyleClass *style_class)
   style_class->draw_diamond = draw_diamond;
   style_class->draw_string = draw_string;
   style_class->draw_box = draw_box;
-  //style_class->draw_flat_box = draw_flat_box;
+  /* style_class->draw_flat_box = draw_flat_box; */
   style_class->draw_check = draw_check;
   style_class->draw_option = draw_option;
   style_class->draw_tab = draw_tab;
